EpubContentType enum
Values
- xhtml11 → const EpubContentType
- dtbook → const EpubContentType
- dtbookNCX → const EpubContentType
- oeb1Document → const EpubContentType
- xml → const EpubContentType
- css → const EpubContentType
- oeb1CSS → const EpubContentType
- imageGIF → const EpubContentType
- imageJPEG → const EpubContentType
- imagePNG → const EpubContentType
- imageSVG → const EpubContentType
- imageBMP → const EpubContentType
- fontTrueType → const EpubContentType
- fontOpenType → const EpubContentType
- other → const EpubContentType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EpubContentType> - A constant List of the values in this enum, in order of their declaration.