EpubNavigationDocTitle class

Constructors

EpubNavigationDocTitle({List<String> titles = const <String>[]})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titles List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(covariant EpubNavigationDocTitle other) bool
The equality operator.
override