SplitInfo class

Information about split part extracted from CFI string.

Constructors

SplitInfo({required int splitPart, required int totalParts, required int position, required int length})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
final
position int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitPart int
final
totalParts int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited