AnnotationExport class
Export data structure for annotations.
Constructors
-
AnnotationExport({required String bookId, required List<
Annotation> annotations, required DateTime exportTimestamp, required String version}) -
const
-
AnnotationExport.fromJson(Map<
String, dynamic> json) -
Creates from JSON.
factory
Properties
-
annotations
→ List<
Annotation> -
final
- bookId → String
-
final
- exportTimestamp → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON for serialization.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited