PositionStorage class abstract
Abstract interface for position storage implementations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteBookData(
String bookId) → Future< void> - Deletes all data for a book.
-
getMilestones(
String bookId) → Future< List< ReadingMilestone> > - Gets all milestones for a book, ordered by timestamp descending.
-
getPosition(
String bookId) → Future< ReadingPosition?> - Gets the saved reading position for a book.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveMilestone(
ReadingMilestone milestone) → Future< void> - Saves a reading milestone.
-
savePosition(
ReadingPosition position) → Future< void> - Saves a reading position.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited